DecapsulationKey768

Type Alias DecapsulationKey768 

pub type DecapsulationKey768 = DecapsulationKey;
An ML-KEM-768 DecapsulationKey which provides the ability to generate a new key pair, and decapsulate an encapsulated shared key.

Aliased Type

pub struct DecapsulationKey768 {
    dk_pke: MaybeBox<DecryptionKey<MlKem768>>,
    ek: EncapsulationKey<MlKem768>,
    d: Option<MaybeBox<Array<u8, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>>>,
    z: MaybeBox<Array<u8, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>>,
}

Fields

dk_pke: MaybeBox<DecryptionKey<MlKem768>>

Decryption key.

ek: EncapsulationKey<MlKem768>

Associated encapsulation key.

d: Option<MaybeBox<Array<u8, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>>>

Seed this key was initialized from.

z: MaybeBox<Array<u8, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>>

Random string used during the implicit rejection process.