EncapsulationKey1024

Type Alias EncapsulationKey1024 

pub type EncapsulationKey1024 = EncapsulationKey;
An ML-KEM-1024 EncapsulationKey provides the ability to encapsulate a shared key so that it can only be decapsulated by the holder of the corresponding decapsulation key.

Aliased Type

pub struct EncapsulationKey1024 {
    ek_pke: MaybeBox<EncryptionKey<MlKem1024>>,
    h: Array<u8, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>,
}

Fields

ek_pke: MaybeBox<EncryptionKey<MlKem1024>>h: Array<u8, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>