EncapsulationKey512

Type Alias EncapsulationKey512 

pub type EncapsulationKey512 = EncapsulationKey;
An ML-KEM-512 EncapsulationKey provides the ability to encapsulate a shared key so that it can only be decapsulated by the holder of the corresponding decapsulation key.

Aliased Type

pub struct EncapsulationKey512 {
    ek_pke: MaybeBox<EncryptionKey<MlKem512>>,
    h: Array<u8, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>,
}

Fields

ek_pke: MaybeBox<EncryptionKey<MlKem512>>h: Array<u8, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>