pub type EncapsulationKey768 = EncapsulationKey;Expand description
An ML-KEM-768 EncapsulationKey provides the ability to encapsulate a shared key so that it
can only be decapsulated by the holder of the corresponding decapsulation key.
Aliased Type
pub struct EncapsulationKey768 {
ek_pke: MaybeBox<EncryptionKey<MlKem768>>,
h: Array<u8, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>,
}Fields
ek_pke: MaybeBox<EncryptionKey<MlKem768>>h: Array<u8, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>